<script setup>
import { getCurrentInstance, ref, watch, reactive } from 'vue';
import { useRouter } from "vue-router";
import { get, post, postForm } from '@/utils/request.js'
import { message, Modal } from 'ant-design-vue';
import { logout } from '@/config.js';
import { formatMessage } from '@/utils/localeUtils.js';
import useTableSearch from '@/utils/tableUtils.jsx';
const context = getCurrentInstance()?.appContext.config.globalProperties;

const router = useRouter();

const TABLE_KEY = 'table-locDetl';

let tableData = ref([]);
let open = ref(false);
const orderDetlId = ref(null);

const showWidth = ref("60%")

const {
    getColumnSearchProps,
} = useTableSearch();

const state = reactive({
    selectedRowKeys: [],
    loading: false,
    columns: [],
});

state.columns = [
    {
        title: formatMessage('db.man_task.task_no', '任务编号'),
        dataIndex: 'taskNo',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('taskNo'),
    },
    {
        title: formatMessage('db.man_task.task_sts', '任务状态'),
        dataIndex: 'taskSts$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('taskSts$'),
    },
    {
        title: formatMessage('db.man_task.task_type', '任务类型'),
        dataIndex: 'taskType$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('taskType$'),
    },
    {
        title: formatMessage('db.man_task.io_pri', '优先级'),
        dataIndex: 'ioPri',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('ioPri'),
    },
    {
        title: formatMessage('db.man_task.origin_loc', '源库位'),
        dataIndex: 'originLoc',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('originLoc'),
    },
    {
        title: formatMessage('db.man_task.target_loc', '目标库位'),
        dataIndex: 'targetLoc',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('targetLoc'),
    },
    {
        title: formatMessage('db.man_task.origin_site', '源站点'),
        dataIndex: 'originSite',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('originSite'),
    },
    {
        title: formatMessage('db.man_task.target_site', '目标站点'),
        dataIndex: 'targetSite',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('targetSite'),
    },
    {
        title: formatMessage('db.man_task.barcode', '托盘码'),
        dataIndex: 'barcode',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('barcode'),
    },
    {
        title: formatMessage('db.man_task.status', '状态'),
        dataIndex: 'status$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('status$'),
    },
    {
        title: formatMessage('db.man_task.create_time', '添加时间'),
        dataIndex: 'createTime$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('createTime$'),
    },
    {
        title: formatMessage('db.man_task.create_by', '添加人员'),
        dataIndex: 'createBy$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('createBy$'),
    },
    {
        title: formatMessage('db.man_task.update_time', '修改时间'),
        dataIndex: 'updateTime$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('updateTime$'),
    },
    {
        title: formatMessage('db.man_task.update_by', '修改人员'),
        dataIndex: 'updateBy$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('updateBy$'),
    },
    {
        title: formatMessage('db.man_task.memo', '备注'),
        dataIndex: 'memo',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('memo'),
    },
];

const handleOk = () => {
    open.value = false;
}

const handleCancel = () => {
    open.value = false;
    orderDetlId.value = null;
}

watch(orderDetlId, (newVal, oldVal) => {
    if (newVal != null) {
        get("/api/task/orderDetlId/" + newVal, {}).then((resp) => {
            let result = resp.data;
            tableData.value = result.data;
        })
    }
})

defineExpose({
    tableData,
    orderDetlId,
    open,
    showWidth,
})

</script>

<script>
export default {
    name: 'workTaskComponent'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open" :width="showWidth" @ok="handleOk" @cancel="handleCancel">
            <a-table :data-source="tableData" :defaultExpandAllRows="false" :key="TABLE_KEY" rowKey="id"
                :scroll="{ y: 768 }" :columns="state.columns">
            </a-table>
        </a-modal>
    </div>
</template>

<style></style>
